"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const jest_file_snapshot_1 = require("jest-file-snapshot");
const __1 = __importDefault(require(".."));
const consts_1 = require("../consts");
expect.extend({ toMatchFile: jest_file_snapshot_1.toMatchFile });
const args = (cwd, template, dest = '') => ({
    cwd,
    template,
    dest,
    $0: '_',
    _: [],
});
describe('Given the tokens command handler', () => {
    const tempThemesDir = path_1.default.resolve(__dirname, 'themes');
    const tempThemeWebPath = path_1.default.resolve(__dirname, 'themes/theme.fixture.css');
    const tempThemeJSONPath = path_1.default.resolve(__dirname, 'themes/theme.fixture.json');
    const snapFolder = path_1.default.resolve(__dirname, '__file_snapshots__');
    afterAll(async () => {
        await fs_extra_1.default.remove(tempThemesDir);
    });
    describe('when a template has not `-template` in name', () => {
        it('should throw an error', async () => {
            const argv = args(__dirname, 'some-wrong');
            // OMG JEST and throw async is bad!
            try {
                await __1.default.handler(argv);
            }
            catch (error) {
                expect(error.message).toBe(consts_1.MESSAGES.errors.templateNotCorrect);
            }
        });
    });
    describe('when template is provided correctly', () => {
        it('should create a themes folder with Web and JSON version of the tokens', async () => {
            const argv = args(__dirname, 'fixtures/theme-template.fixture.js', tempThemesDir);
            await __1.default.handler(argv);
            const webFileExist = await fs_extra_1.default.pathExists(tempThemeWebPath);
            const jsonFileExist = await fs_extra_1.default.pathExists(tempThemeJSONPath);
            expect(webFileExist).toBe(true);
            expect(jsonFileExist).toBe(true);
        });
        it('should match the snapshots', async () => {
            const webTheme = await fs_extra_1.default.readFile(tempThemeWebPath, 'utf-8');
            const jsonTheme = await fs_extra_1.default.readFile(tempThemeJSONPath, 'utf-8');
            expect(webTheme).toMatchFile(path_1.default.resolve(snapFolder, 'web.snapshot'));
            expect(jsonTheme).toMatchFile(path_1.default.resolve(snapFolder, 'json.snapshot'));
        });
    });
});
