"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const cssbeautify_1 = __importDefault(require("cssbeautify"));
const consts_1 = require("./consts");
const webCSSTemplate = `
  :root {
    [vars]
  }
`;
const cwdPath = (cwd, ...givenPaths) => path_1.default.resolve(cwd, ...givenPaths);
const tokensCommand = {
    command: 'tokens [template] [dest]',
    describe: 'Create a new Web and JSON theme given a template.',
    builder: {
        cwd: {
            description: 'CWD to run the CLI to',
            type: 'string',
            default: process.cwd(),
        },
        template: {
            description: 'A JS template file that is using our tokens',
            demandOption: true,
            type: 'string',
        },
        dest: {
            description: 'Destination where to save the final theme',
            default: 'themes',
        },
    },
    async handler(argv) {
        const { template, dest, cwd } = argv;
        if (!template.includes('-template')) {
            throw new Error(consts_1.MESSAGES.errors.templateNotCorrect);
        }
        const templateJSONImport = await Promise.resolve().then(() => __importStar(require(cwdPath(cwd, template))));
        const templateJSON = Object.assign({}, templateJSONImport.default);
        const outputName = path_1.default.basename(template).replace('-template', '').replace('.js', '');
        const pathToJSON = cwdPath(cwd, dest, `${outputName}.json`);
        const pathToWeb = cwdPath(cwd, dest, `${outputName}.css`);
        const webCSSVars = Object.keys(templateJSON).reduce((acc, key) => acc.concat(`--${key}: ${templateJSON[key]};\n`), '');
        await fs_extra_1.default.ensureDir(cwdPath(cwd, dest));
        await fs_extra_1.default.writeJSON(pathToJSON, templateJSON, { spaces: 2 });
        await fs_extra_1.default.writeFile(pathToWeb, cssbeautify_1.default(webCSSTemplate.replace('[vars]', webCSSVars), { indent: '  ', autosemicolon: true }));
        process.stdout.write(consts_1.MESSAGES.success.themeGenerated);
    },
};
exports.default = tokensCommand;
